<?php
namespace App\Controller;

use App\Controller\AppController;

/**
 * Completadors Controller
 *
 * @property \App\Model\Table\CompletadorsTable $Completadors
 * @method \App\Model\Entity\Completador[]|\Cake\Datasource\ResultSetInterface paginate($object = null, array $settings = [])
 */
class CompletadorsController extends AppController
{
    /**
     * Index method
     *
     * @return \Cake\Http\Response|null|void Renders view
     */
    public function index()
    {
        $completadors = $this->paginate($this->Completadors);

        $this->set(compact('completadors'));
    }

    /**
     * View method
     *
     * @param string|null $id Completador id.
     * @return \Cake\Http\Response|null|void Renders view
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function view($id = null)
    {
        $completador = $this->Completadors->get($id, [
            'contain' => [],
        ]);

        $this->set(compact('completador'));
    }

    /**
     * Add method
     *
     * @return \Cake\Http\Response|null|void Redirects on successful add, renders view otherwise.
     */
    public function add()
    {
        $completador = $this->Completadors->newEntity();
        if ($this->request->is('post')) {
            $completador = $this->Completadors->patchEntity($completador, $this->request->getData());
            if ($this->Completadors->save($completador)) {
                $this->Flash->success(__('The completador has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The completador could not be saved. Please, try again.'));
        }
        $this->set(compact('completador'));
    }

    /**
     * Edit method
     *
     * @param string|null $id Completador id.
     * @return \Cake\Http\Response|null|void Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function edit($id = null)
    {
        $completador = $this->Completadors->get($id, [
            'contain' => [],
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $completador = $this->Completadors->patchEntity($completador, $this->request->getData());
            if ($this->Completadors->save($completador)) {
                $this->Flash->success(__('The completador has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The completador could not be saved. Please, try again.'));
        }
        $this->set(compact('completador'));
    }

    /**
     * Delete method
     *
     * @param string|null $id Completador id.
     * @return \Cake\Http\Response|null|void Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $completador = $this->Completadors->get($id);
        if ($this->Completadors->delete($completador)) {
            $this->Flash->success(__('The completador has been deleted.'));
        } else {
            $this->Flash->error(__('The completador could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'index']);
    }
}
