<?php
namespace App\Controller;

use App\Controller\AppController;
use Cake\ORM\TableRegistry ; 
use Cake\Datasource\ConnectionManager;

/**
 * Empleados Controller
 *
 * @property \App\Model\Table\EmpleadosTable $Empleados
 */
class EmpleadosController extends AppController
{

    /**
     * Index method
     *
     * @return \Cake\Network\Response|null
     */
    public function index()
    {
        $empleados = $this->paginate($this->Empleados);

        $this->set(compact('empleados'));
        $this->set('_serialize', ['empleados']);
    }
    
   

    /**
     * View method
     *
     * @param string|null $id Empleado id.
     * @return \Cake\Network\Response|null
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function view($id = null)
    {
        $empleado = $this->Empleados->get($id, [
            'contain' => ['Users']
        ]);

        $this->set('empleado', $empleado);
        $this->set('_serialize', ['empleado']);
    }

    /**
     * Add method
     *
     * @return \Cake\Network\Response|null Redirects on successful add, renders view otherwise.
     */
    public function add()
    {
        $empleado = $this->Empleados->newEntity();
        if ($this->request->is('post')) {
            $empleado = $this->Empleados->patchEntity($empleado, $this->request->data);
            if ($this->Empleados->save($empleado)) {
                $this->Flash->success(__('The empleado has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The empleado could not be saved. Please, try again.'));
        }
        $users = $this->Empleados->Users->find('list', ['limit' => 200]);
        $this->set(compact('empleado', 'users'));
        $this->set('_serialize', ['empleado']);
    }

    /**
     * Edit method
     *
     * @param string|null $id Empleado id.
     * @return \Cake\Network\Response|null Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function edit($id = null)
    {
        $empleado = $this->Empleados->get($id, [
            'contain' => ['Users']
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $empleado = $this->Empleados->patchEntity($empleado, $this->request->data);
            if ($this->Empleados->save($empleado)) {
                $this->Flash->success(__('The empleado has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The empleado could not be saved. Please, try again.'));
        }
        $users = $this->Empleados->Users->find('list', ['limit' => 200]);
        $this->set(compact('empleado', 'users'));
        $this->set('_serialize', ['empleado']);
    }

    /**
     * Delete method
     *
     * @param string|null $id Empleado id.
     * @return \Cake\Network\Response|null Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $empleado = $this->Empleados->get($id);
        if ($this->Empleados->delete($empleado)) {
            $this->Flash->success(__('The empleado has been deleted.'));
        } else {
            $this->Flash->error(__('The empleado could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'index']);
    }
    
    public function ventas($mes = null){
        
        $mesletra=array(1=>"ENERO","FEBRERO","MARZO","ABRIL","MAYO","JUNIO","JULIO","AGOSTO","SEPTIEMBRE","OCTUBRE","NOVIEMBRE","DICIEMBRE");
        $hoy = getdate();
        $desde = "";
        $hasta = "";
        $ultimodia=array(1=>"31","28","31","30","31","30","31","31","30","31","30","31");
        $desde = "01/".$mes."/".$hoy['year'];
        $hasta = $ultimodia[$mes]."/".$mes."/".$hoy['year'];
        $sqlwhere = "to_date(fecha,'dd/MM/yyyy')  between to_date('".$desde."','dd/mm/yyyy') and to_date('".$hasta."','dd/mm/yyyy') ";
        
        
        $empleados  =  TableRegistry::get('empleados');
        $sqlempleado = "cargo ilike '%VEND%'";
        $queryemple = $empleados->find('all', ['conditions' => [$sqlempleado], 'order by' => 'nombre']);
        $conventas = array();
        $sinventas = array();

        $sumatoria = 0;

        foreach ($queryemple as $empleado):
            $connection = ConnectionManager::get('default');
            $sql = "select * from ventas where vendedors = ".  $empleado->id . " and " . $sqlwhere;
            $results = $connection->execute($sql)->fetchAll('assoc');
            $cantidad = 0;
            $aux = array();
            foreach ($results as $v):
                $cantidad ++;
            endforeach;

            $sumatoria = $sumatoria + $cantidad;

            if($cantidad>0){
                $auxs = array (
                    $empleado->id,
                    $empleado->nombre . ' ' . $empleado->apellido,
                    $cantidad
                );
                array_push($conventas, $auxs);
            }else{
                $auxs = array (
                    $empleado->id,
                    $empleado->nombre . ' ' . $empleado->apellido,
                    $cantidad
                );
                array_push($sinventas, $auxs);
            }
            $connection->disconnect();
       endforeach;
       $this->set('empleados', $conventas);
       $this->set('empleadosin', $sinventas);
       $this->set('mes' , $mesletra[$mes] );
       $this->set('sumatoria', $sumatoria);
    }
    

 public function ventasdic(){
        
        $mesletra=array(1=>"ENERO","FEBRERO","MARZO","ABRIL","MAYO","JUNIO","JULIO","AGOSTO","SEPTIEMBRE","OCTUBRE","NOVIEMBRE","DICIEMBRE");
        $hoy = getdate();
        $desde = "";
        $hasta = "";
        $ultimodia=array(1=>"31","28","31","30","31","30","31","31","30","31","30","31");
        $desde = "01/12/2019";
        $hasta = "31/12/2019";
        $sqlwhere = "to_date(fecha,'dd/MM/yyyy')  between to_date('".$desde."','dd/mm/yyyy') and to_date('".$hasta."','dd/mm/yyyy') ";
        
        
        $empleados  =  TableRegistry::get('empleados');
        $sqlempleado = "cargo ilike '%VEND%'";
        $queryemple = $empleados->find('all', ['conditions' => [$sqlempleado], 'order by' => 'nombre']);
        $conventas = array();
        $sinventas = array();
        $sumatoria = 0;
        foreach ($queryemple as $empleado):
            $connection = ConnectionManager::get('default');
            $sql = "select * from ventas where vendedors = ".  $empleado->id . " and " . $sqlwhere;
            $results = $connection->execute($sql)->fetchAll('assoc');
            $cantidad = 0;
            $aux = array();
            foreach ($results as $v):
                $cantidad ++;
            endforeach; 
            $sumatoria = $sumatoria + $cantidad;

            if($cantidad>0){
                $auxs = array (
                    $empleado->id,
                    $empleado->nombre . ' ' . $empleado->apellido,
                    $cantidad
                );
                array_push($conventas, $auxs);
            }else{
                $auxs = array (
                    $empleado->id,
                    $empleado->nombre . ' ' . $empleado->apellido,
                    $cantidad
                );
                array_push($sinventas, $auxs);
            }
            $connection->disconnect();
       endforeach;
       $this->set('empleados', $conventas);
       $this->set('empleadosin', $sinventas);
       $this->set('mes' , $mesletra[$mes] );
       $this->set('sumatoria', $sumatoria);
    }

     public function ventasnov(){
        
        $mesletra=array(1=>"ENERO","FEBRERO","MARZO","ABRIL","MAYO","JUNIO","JULIO","AGOSTO","SEPTIEMBRE","OCTUBRE","NOVIEMBRE","DICIEMBRE");
        $hoy = getdate();
        $desde = "";
        $hasta = "";
        $ultimodia=array(1=>"31","28","31","30","31","30","31","31","30","31","30","31");
        $desde = "01/11/2019";
        $hasta = "30/11/2019";
        $sqlwhere = "to_date(fecha,'dd/MM/yyyy')  between to_date('".$desde."','dd/mm/yyyy') and to_date('".$hasta."','dd/mm/yyyy') ";
        
        
        $empleados  =  TableRegistry::get('empleados');
        $sqlempleado = "cargo ilike '%VEND%'";
        $queryemple = $empleados->find('all', ['conditions' => [$sqlempleado], 'order by' => 'nombre']);
        $conventas = array();
        $sinventas = array();
        $sumatoria = 0;
        foreach ($queryemple as $empleado):
            $connection = ConnectionManager::get('default');
            $sql = "select * from ventas where vendedors = ".  $empleado->id . " and " . $sqlwhere;
            $results = $connection->execute($sql)->fetchAll('assoc');
            $cantidad = 0;
            $aux = array();
            foreach ($results as $v):
                $cantidad ++;
            endforeach;

             $sumatoria = $sumatoria + $cantidad;

            if($cantidad>0){
                $auxs = array (
                    $empleado->id,
                    $empleado->nombre . ' ' . $empleado->apellido,
                    $cantidad
                );
                array_push($conventas, $auxs);
            }else{
                $auxs = array (
                    $empleado->id,
                    $empleado->nombre . ' ' . $empleado->apellido,
                    $cantidad
                );
                array_push($sinventas, $auxs);
            }
            
            $connection->disconnect();
            
       endforeach;
       $this->set('empleados', $conventas);
       $this->set('empleadosin', $sinventas);
       $this->set('mes' , $mesletra[$mes] );
       $this->set('sumatoria', $sumatoria);
    }

       public function mes()
    {

        $hoy = getdate();
        $mesestotal = $hoy['mon'];
        $pila = array();

        
        for ($i = 1; $i <= $mesestotal; $i++) {
           array_push($pila, $i);
        }
        $this->set('meses', $pila);
    }


     public function dia($mess = null)
    {

         $mesesN=array(1=>"ENERO","FEBRERO","MARZO","ABRIL","MAYO","JUNIO","JULIO",
             "AGOSTO","SEPTIEMBRE","OCTUBRE","NOVIEMBRE","DICIEMBRE");
      
        $mesestotal = $mess;
        $pila = array();

        $ultimodia=array(1=>31,28,31,30,31,30,31,31,30,31,30,31);
         $this->set('mes', $mesesN[$mess]);
        
        for ($i = 1; $i <= $ultimodia[$mesestotal]; $i++) {
           array_push($pila, $i);
        }
        $this->set('meses', $pila);
        $this->set('mess', $mess);
    }

    
    
}
