<?php
namespace App\Controller;

use App\Controller\AppController;

/**
 * Ubicas Controller
 *
 * @property \App\Model\Table\UbicasTable $Ubicas
 *
 * @method \App\Model\Entity\Ubica[]|\Cake\Datasource\ResultSetInterface paginate($object = null, array $settings = [])
 */
class UbicasController extends AppController
{

    /**
     * Index method
     *
     * @return \Cake\Http\Response|void
     */
    public function index()
    {
        $ubicas = $this->paginate($this->Ubicas);

        $this->set(compact('ubicas'));
    }

    /**
     * View method
     *
     * @param string|null $id Ubica id.
     * @return \Cake\Http\Response|void
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function view($id = null)
    {
        $ubica = $this->Ubicas->get($id, [
            'contain' => ['Depositos']
        ]);

        $this->set('ubica', $ubica);
    }

    /**
     * Add method
     *
     * @return \Cake\Http\Response|null Redirects on successful add, renders view otherwise.
     */
    public function add()
    {
        $ubica = $this->Ubicas->newEntity();
        if ($this->request->is('post')) {
            $ubica = $this->Ubicas->patchEntity($ubica, $this->request->getData());
            if ($this->Ubicas->save($ubica)) {
                $this->Flash->success(__('The ubica has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The ubica could not be saved. Please, try again.'));
        }
        $depositos = $this->Ubicas->Depositos->find('list', ['limit' => 200]);
        $this->set(compact('ubica', 'depositos'));
    }

    /**
     * Edit method
     *
     * @param string|null $id Ubica id.
     * @return \Cake\Http\Response|null Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function edit($id = null)
    {
        $ubica = $this->Ubicas->get($id, [
            'contain' => ['Depositos']
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $ubica = $this->Ubicas->patchEntity($ubica, $this->request->getData());
            if ($this->Ubicas->save($ubica)) {
                $this->Flash->success(__('The ubica has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The ubica could not be saved. Please, try again.'));
        }
        $depositos = $this->Ubicas->Depositos->find('list', ['limit' => 200]);
        $this->set(compact('ubica', 'depositos'));
    }

    /**
     * Delete method
     *
     * @param string|null $id Ubica id.
     * @return \Cake\Http\Response|null Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $ubica = $this->Ubicas->get($id);
        if ($this->Ubicas->delete($ubica)) {
            $this->Flash->success(__('The ubica has been deleted.'));
        } else {
            $this->Flash->error(__('The ubica could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'index']);
    }
}
