<?php
namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * Chaperias Model
 *
 * @method \App\Model\Entity\Chaperia get($primaryKey, $options = [])
 * @method \App\Model\Entity\Chaperia newEntity($data = null, array $options = [])
 * @method \App\Model\Entity\Chaperia[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\Chaperia|bool save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Chaperia|bool saveOrFail(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Chaperia patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\Chaperia[] patchEntities($entities, array $data, array $options = [])
 * @method \App\Model\Entity\Chaperia findOrCreate($search, callable $callback = null, $options = [])
 */
class ChaperiasTable extends Table
{

    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config)
    {
        parent::initialize($config);

        $this->setTable('chaperias');
        $this->setDisplayField('id');
        $this->setPrimaryKey('id');

        $this->belongsTo('funcionariochaperia', [
            'foreignKey' => 'empleado'
        ]);

    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator)
    {
        $validator
            ->integer('id')
            ->allowEmpty('id', 'create');

        $validator
            ->scalar('fecha')
            ->maxLength('fecha', 250)
            ->allowEmpty('fecha');

        $validator
            ->integer('empleado')
            ->allowEmpty('empleado');

        $validator
            ->integer('usuarioapp')
            ->allowEmpty('usuarioapp');

        $validator
            ->scalar('chasis')
            ->maxLength('chasis', 250)
            ->allowEmpty('chasis');

        $validator
            ->numeric('monto')
            ->allowEmpty('monto');

        $validator
            ->numeric('cantidadpieza')
            ->allowEmpty('cantidadpieza');

        $validator
            ->integer('total')
            ->allowEmpty('total');

        $validator
            ->integer('entrega')
            ->allowEmpty('entrega');

        $validator
            ->scalar('fechaultimaentrega')
            ->maxLength('fechaultimaentrega', 25)
            ->allowEmpty('fechaultimaentrega');

        $validator
            ->integer('estado')
            ->allowEmpty('estado');

        return $validator;
    }

    public function buildRules(RulesChecker $rules)
    {
        $rules->add($rules->existsIn(['empleado'], 'funcionariochaperia'));

        return $rules;
    }
}
