<?php
namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * Simuladors Model
 *
 * @property \App\Model\Table\StocksTable|\Cake\ORM\Association\BelongsTo $Stocks
 * @property \App\Model\Table\EmpleadosTable|\Cake\ORM\Association\BelongsTo $Empleados
 *
 * @method \App\Model\Entity\Simulador get($primaryKey, $options = [])
 * @method \App\Model\Entity\Simulador newEntity($data = null, array $options = [])
 * @method \App\Model\Entity\Simulador[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\Simulador|bool save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Simulador|bool saveOrFail(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Simulador patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\Simulador[] patchEntities($entities, array $data, array $options = [])
 * @method \App\Model\Entity\Simulador findOrCreate($search, callable $callback = null, $options = [])
 */
class SimuladorsTable extends Table
{

    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config)
    {
        parent::initialize($config);

        $this->setTable('simuladors');
        $this->setDisplayField('id');
        $this->setPrimaryKey('id');

        $this->belongsTo('Stocks', [
            'foreignKey' => 'producto_id'
        ]);
        $this->belongsTo('Empleados', [
            'foreignKey' => 'empleado_id'
        ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator)
    {
        $validator
            ->integer('id')
            ->allowEmpty('id', 'create');

        $validator
            ->scalar('chasis')
            ->maxLength('chasis', 200)
            ->allowEmpty('chasis');

        $validator
            ->integer('meses')
            ->allowEmpty('meses');

        $validator
            ->integer('moneda')
            ->allowEmpty('moneda');

        $validator
            ->numeric('total')
            ->allowEmpty('total');

        $validator
            ->numeric('entrega')
            ->allowEmpty('entrega');

        $validator
            ->numeric('saldo')
            ->allowEmpty('saldo');

        $validator
            ->integer('cuota')
            ->allowEmpty('cuota');

        $validator
            ->numeric('montocuota')
            ->allowEmpty('montocuota');

        $validator
            ->integer('refuerzo')
            ->allowEmpty('refuerzo');

        $validator
            ->numeric('montorefuerzo')
            ->allowEmpty('montorefuerzo');

        $validator
            ->scalar('fecha')
            ->maxLength('fecha', 200)
            ->allowEmpty('fecha');

        $validator
            ->scalar('hora')
            ->maxLength('hora', 200)
            ->allowEmpty('hora');

        $validator
            ->integer('tipopersona')
            ->notEmpty('tipopersona', 'Seleccione una opción!');

        $validator
            ->scalar('ci')
            ->maxLength('ci', 200)
            ->add('ci', [
                'length' => [
                    'rule' => ['minLength', 6],
                    'message' => 'No corresponde a una cédula de identidad válida!',
                ]
            ])
            ->notEmpty('ci', 'Rellene este campo!');

        $validator
            ->scalar('telefono')
            ->maxLength('telefono', 200)
            ->add('telefono', [
                'length' => [
                    'rule' => ['minLength', 9],
                    'message' => 'No corresponde a un número de celular o teléfono valido!',
                ]
            ])
            ->notEmpty('telefono', 'Rellene este campo!');

        $validator
            ->integer('aleatorio')
            ->allowEmpty('aleatorio');

        $validator
            ->integer('veces')
            ->allowEmpty('veces');

        $validator
            ->integer('vecesgerente')
            ->allowEmpty('vecesgerente');

        $validator
            ->integer('vecessergio')
            ->allowEmpty('vecessergio');

        $validator
            ->integer('estado')
            ->allowEmpty('estado');

        $validator
            ->integer('borrado')
            ->allowEmpty('borrado');

        $validator
            ->integer('confirmado')
            ->allowEmpty('confirmado');

        return $validator;
    }

    /**
     * Returns a rules checker object that will be used for validating
     * application integrity.
     *
     * @param \Cake\ORM\RulesChecker $rules The rules object to be modified.
     * @return \Cake\ORM\RulesChecker
     */
    public function buildRules(RulesChecker $rules)
    {
        $rules->add($rules->existsIn(['producto_id'], 'Stocks'));
        $rules->add($rules->existsIn(['empleado_id'], 'Empleados'));

        return $rules;
    }
}
